==> cscec5b-dataexchange-impl-3.0.1-20230523.093306-73-sources.jar: com/ejianc/business/dataexchange/mapper/CmContractInfoMapper.java <==
package com.ejianc.business.dataexchange.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.dataexchange.vo.CmContractInfoVO;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;


/**
 * <p>
 * 库存组织 Mapper 接口
 * </p>
 *
 * @author Brin
 * @since 2020-10-29 08:02:02
 */
@Mapper
public interface CmContractInfoMapper extends BaseMapper<CmContractInfoVO> {

     List<CmContractInfoVO> querySubContractInfoPage(Page<CmContractInfoVO> pages, @Param(Constants.WRAPPER) QueryWrapper queryWrapper, @Param("supplierId") Long supplierId, @Param("pkContract") String pkContract);

     List<CmContractInfoVO> queryMatContractInfoPage(Page<CmContractInfoVO> pages, @Param(Constants.WRAPPER) QueryWrapper queryWrapper,
                                                     @Param("supplierId") Long supplierId, @Param("pkContract") String pkContract,
                                                     @Param("pkProject") String pkProject );

     List<CmContractInfoVO> queryLeaseContractInfoById(String pkContract);

     List<CmContractInfoVO> queryMatContractInfoById(String pkContract);

     List<CmContractInfoVO> queryContractInfoPageOld(Page<CmContractInfoVO> pages, @Param(Constants.WRAPPER) QueryWrapper queryWrapper, @Param("supplierId") Long supplierId, @Param("pkContract") String pkContract);

}

==> cscec5b-dataexchange-impl-3.0.1-20240726.114344-97-sources.jar: com/ejianc/business/dataexchange/mapper/CmContractInfoMapper.java <==
package com.ejianc.business.dataexchange.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.dataexchange.vo.CmContractInfoVO;
import com.ejianc.business.dataexchange.vo.LeaseInfoPriceRecordVO;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;


/**
 * <p>
 * 库存组织 Mapper 接口
 * </p>
 *
 * @author Brin
 * @since 2020-10-29 08:02:02
 */
@Mapper
public interface CmContractInfoMapper extends BaseMapper<CmContractInfoVO> {

     List<CmContractInfoVO> querySubContractInfoPage(Page<CmContractInfoVO> pages, @Param(Constants.WRAPPER) QueryWrapper queryWrapper, @Param("supplierId") Long supplierId, @Param("pkContract") String pkContract);

     List<CmContractInfoVO> queryMatContractInfoPage(Page<CmContractInfoVO> pages, @Param(Constants.WRAPPER) QueryWrapper queryWrapper,
                                                     @Param("supplierId") Long supplierId, @Param("pkContract") String pkContract,
                                                     @Param("pkProject") String pkProject );

     List<CmContractInfoVO> queryLeaseContractInfoById(String pkContract);

     List<CmContractInfoVO> queryMatContractInfoById(String pkContract);

     List<CmContractInfoVO> queryContractInfoPageOld(Page<CmContractInfoVO> pages, @Param(Constants.WRAPPER) QueryWrapper queryWrapper, @Param("supplierId") Long supplierId, @Param("pkContract") String pkContract);

    List<LeaseInfoPriceRecordVO> queryLeasePriceById(String pkContract, String pkContractInfo);

     List<CmContractInfoVO> queryLeaseContractInfoPage(Page<CmContractInfoVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper,
                                                       @Param("pkContract") String pkContract, @Param("pkProject")String pkProject);
}
